@@ -8,6 +8,7 @@ from collections.abc import Sequence
 import multiprocessing
 import os
 from typing import Dict
+from typing import Generator
 from typing import List
 from typing import Optional
 from typing import Set
@@ -16,9 +17,13 @@ import hyperthought as ht
 from hyperthought.metadata import MetadataItem
 
 from . import database
+from .database import MetadataApplicationFilter
 from . import utils
 
 
+MAX_PROCESSES = 60
+
+
 class PathNotFoundException(Exception):
     pass
 
@@ -759,6 +764,7 @@ class Manifest:
         if n_processes is None:
             n_processes = multiprocessing.cpu_count() * 2
 
+        n_processes = min(n_processes, MAX_PROCESSES)
         files = self.database.get_all_files()
         pool = multiprocessing.Pool(processes=n_processes)
         all_updates = pool.map(_compute_size_hash_and_end_bytes, files)
@@ -795,6 +801,33 @@ class Manifest:
         """Get the sum of file sizes for all files in the manifest."""
         return self.database.get_total_size()
 
+    def get_metadata_application(
+        self,
+        metadata_id: int,
+        filter_: MetadataApplicationFilter
+    ) -> Generator[Dict, Optional[None], Optional[None]]:
+        """
+        Get ids for files to which metadata will be applied.
+
+        Parameters
+        ----------
+        metadata_id : int
+            Id of the Metadata record of interest.
+        filter_ : MetadataApplicationFilter
+            Enum instance used to specify filter for results.
+
+        Yields
+        ------
+        Ids for files to which metadata will be applied.
+        """
+        generator = self.database.get_metadata_application(
+            metadata_id=metadata_id,
+            filter_=filter_,
+        )
+
+        for file_id in generator:
+            yield file_id
+
     def close(self, compute_file_info: bool = True) -> None:
         """
         Close the manifest (database).
