@@ -2,6 +2,7 @@
 Database functionality for a file transfer manifest.
 """
 
+from enum import Enum
 from enum import IntEnum
 import os
 import sqlite3
@@ -9,7 +10,6 @@ from typing import Dict
 from typing import Generator
 from typing import List
 from typing import Optional
-from typing import Set
 
 import hyperthought as ht
 from hyperthought.metadata import MetadataItem
@@ -32,6 +32,7 @@ class FileStatus(IntEnum):
     UPLOAD_ERROR = 10
     CREATION_ERROR = 11
     UNKNOWN_ERROR = 12
+    METADATA_UPDATE_ERROR = 13
 
 
 class ParserStatus(IntEnum):
@@ -42,6 +43,16 @@ class ParserStatus(IntEnum):
     PARSER_ERROR = 3
 
 
+class MetadataApplicationFilter(Enum):
+    """
+    Enum used to filter results when getting metadata application records.
+    """
+
+    FILES_ONLY = 1
+    FOLDERS_ONLY = 2
+    FILES_AND_FOLDERS = 3
+
+
 class Database:
     """
     Manager class an upload job embedded database.
@@ -1338,6 +1349,76 @@ class Database:
         if commit:
             self.connection.commit()
 
+    def get_metadata_application(
+        self,
+        metadata_id: int,
+        filter_: MetadataApplicationFilter
+    ) -> Generator[Dict, Optional[None], Optional[None]]:
+        """
+        Get ids for files to which metadata will be applied.
+
+        Parameters
+        ----------
+        metadata_id : int
+            Id of the Metadata record of interest.
+        filter_ : MetadataApplicationFilter
+            Specify filter for results.
+
+        Yields
+        ------
+        Ids for files to which metadata will be applied.
+        """
+        if filter_ == MetadataApplicationFilter.FILES_ONLY:
+            sql = """
+            SELECT
+                MetadataApplication.file_id
+            FROM
+                Metadata
+                INNER JOIN MetadataApplication
+                    ON Metadata.id = MetadataApplication.metadata_id
+                INNER JOIN File
+                    ON MetadataApplication.file_id = File.id
+            WHERE
+                Metadata.id = :metadata_id
+                AND
+                NOT File.is_folder
+            """
+        elif filter_ == MetadataApplicationFilter.FOLDERS_ONLY:
+            sql = """
+            SELECT
+                MetadataApplication.file_id
+            FROM
+                Metadata
+                INNER JOIN MetadataApplication
+                    ON Metadata.id = MetadataApplication.metadata_id
+                INNER JOIN File
+                    ON MetadataApplication.file_id = File.id
+            WHERE
+                Metadata.id = :metadata_id
+                AND
+                File.is_folder
+            """
+        else:
+            sql = """
+            SELECT
+                MetadataApplication.file_id
+            FROM
+                Metadata
+                INNER JOIN MetadataApplication
+                    ON Metadata.id = MetadataApplication.metadata_id
+            WHERE
+                Metadata.id = :metadata_id
+            """
+
+        cursor = self._connection.cursor()
+        cursor.execute(sql, {"metadata_id": metadata_id})
+
+        for row in cursor.fetchall():
+            yield row["file_id"]
+
+        cursor.close()
+
+
     def has_connectivity_errors(self) -> bool:
         """Determine whether connectivity errors occurred."""
         sql = """
@@ -1345,7 +1426,8 @@ class Database:
         FROM File
         WHERE file_status_id IN (
             :upload_error_status_id,
-            :creation_error_status_id
+            :creation_error_status_id,
+            :metadata_update_error_status_id
         )
         """
         cursor = self.connection.cursor()
@@ -1354,6 +1436,8 @@ class Database:
             {
                 "upload_error_status_id": FileStatus.UPLOAD_ERROR.value,
                 "creation_error_status_id": FileStatus.CREATION_ERROR.value,
+                "metadata_update_error_status_id": (
+                    FileStatus.METADATA_UPDATE_ERROR.value),
             },
         )
         row = cursor.fetchone()
